# ClimbFiber_InstructSignals

Centralized data used for the bioRxiv article "Neural instructive signals for associative cerebellar learning" (Silva et al., 2022).

Each folder in this repository contains a Pickled Python dictionary (version 3.6) containing all the data used for the experimental analysis involving Purkinje cell spiking activity (cell-attached recordings, optostimulation) with simultaneous eye-blink conditioning treatments (eyelid tracking, exposure to stimuli). 

## Opening the files

To load the files, just import the pickle module in python and open the filepath like this:

```
import pickle

filepath = "C:\Users\User\Desktop\..."

with open(filepath, "rb") as f:
    Data_dict = pickle.load(f)
    
```

## Structure of the files

### First level:

Inside each data dictionary, the first level contains all the data organized by files of recordings, which correspond to the experimental sessions (e.g. "File 1", "File 2", etc.). There is also an entry to keep track of which files correspond to the same cell and the filename (with important metadata), inside of the entry "Lookups and Constants". Finally, there is an entry called "Spike Rate Org. Data", which contains a simplified analysis of the rates of simple and complex spikes averaged at three epochs: baseline, treatment (laser, airpuff, or LED light) and return.

### File data:

Each file entry possesses 3 dictionary keys with the different treatments/stimulations ("Laser", "LED", "Airpuff"), plus some information about how it was collected (like sampling rates) inside the key "Constants". Inside of each treatment there are sub-dictionaries with the following content:

* Group Replicas Count: Number of repeated exposures to the treatment, that sets the size of the collections inside this sub-dictionary.
* File Suffix ID: Lookup list of indexing numbers identifying the File from which the data has been taken. It has the number of elements defined in "Group Replicas Count".
* LFP Average: Single waves and average of the Low Frequency Band signal (below 2kHz) of the cell-attached ephys recording.
* Spike Wave Averages: Single waves and averages of simple and complex spikes at each treatment epoch (baseline, treatment, return)
* Ephys File Paths & Behav. File Paths: A reference to the original raw data collected in the experiment (used for debugging)
* Ephys Data & Behav. Data: Synchronized, raw data from the cell-attached recordings and the quatification of eye closures respectively.
* Spike Sorting Data: Contains indexes from the raw Ephys Data where either simple and complex spikes are located. And also some spike counts used for the calculation of the "Spike Rate Org. Data" values.
* Trigger Orig. Timings: List of intervals in seconds, positioning the treatment onset and offset in the time of the raw ephys/behavior data.
* Baseline, Treatment and Return Durations: List of time amounts each epoch has per file. Used for the calculation of the "Spike Rate Org. Data" values.

### Other considerations:

Filenames contain information about the experimental sessions such as laser powers, depth of recording electrode, position of laser stimulation (default is cortex, unless "IO" is written), among others.
